##  External ID Field
External ID (externalId) is a standard field that applies to multiple fact sheet types and is not linked to any specific fact sheet type. When you change labels and help texts (translations) for the externalId field, they apply to all fact sheet types where this field is present. Avoid references to a specific fact sheet type in labels and help texts.
If needed, you can create a custom field for external IDs on a specific fact sheet type. To do this, please contact support from the [SAP LeanIX Support![Information published on non-SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/3rd_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.leanix.net%2Fsupport "https://www.leanix.net/support") portal or, if you're an SAP customer, [SAP for Me![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fme.sap.com%2F "https://me.sap.com/") portal.
